@@ -8,6 +8,7 @@
 #' @param on the variables defining on which the pairs of records from \code{x} 
 #'   and \code{y} are compared.
 #' @param minsim minimal similarity score.
+#' @param on_blocking variables for which the pairs have to match.
 #' @param comparators named list of functions with which the variables are compared. 
 #'   This function should accept two vectors. Function should either return a vector
 #'   or a \code{data.table} with multiple columns.
@@ -46,11 +47,17 @@
 #' pairs <- pair_minsim(linkexample1, linkexample2, 
 #'    on = c("postcode", "address"), minsim = 1)
 #' # Either address or postcode has to match to keep a pair
+#' 
+#' data("linkexample1", "linkexample2")
+#' pairs <- pair_minsim(linkexample1, linkexample2, on_blocking = "postcode",
+#'    on = c("lastname", "firstname", "address"), minsim = 2)
+#' # Postcode has to match; from lastname, firstname, address there have to match
+#' # two or more (e.g. one mismatch is allowed).
 #'
 #' @import data.table
 #' @export
-pair_minsim <- function(x, y, on, minsim = 0.0, 
-    comparators = list(default_comparator), default_comparator = identical(), 
+pair_minsim <- function(x, y, on, minsim = 0.0, on_blocking = character(0),
+    comparators = list(default_comparator), default_comparator = cmp_identical(), 
     keep_simsum = TRUE, deduplication = FALSE, add_xy = TRUE) {
   x <- as.data.table(x)
   if (deduplication && !missing(y)) warning("y provided will be ignored.")
@@ -62,8 +69,13 @@ pair_minsim <- function(x, y, on, minsim = 0.0,
   nchunks <- max(ceiling(nx * (ny/ max_size)), 1L)
   group <- floor(seq_len(nrow(x))/(nrow(x)+1)*nchunks)
   idx <- split(seq_len(nrow(x)), group)
-  pairs <- lapply(idx, function(idx, x, y, on, minsim, comparators, deduplication) {
-    pairs <- CJ(.x = idx, .y = seq_len(nrow(y)))
+  pairs <- lapply(idx, function(idx, x, y, on, on_blocking, minsim, comparators, deduplication) {
+    if (length(on_blocking)) {
+      pairs <- pair_blocking(x, y, on = on_blocking, add_xy = FALSE)
+      pairs[, .x := idx[.x]]
+    } else {
+      pairs <- CJ(.x = idx, .y = seq_len(nrow(y)))
+    }
     if (deduplication) pairs <- pairs[.y > .x]
     pairs[, simsum := rep(0, nrow(pairs))]
     for (var in on) {
@@ -73,8 +85,8 @@ pair_minsim <- function(x, y, on, minsim = 0.0,
       pairs[, simsum := simsum + ..cmp]
     }
     pairs[simsum >= minsim]
-  }, x = x, y = y, on = on, minsim = minsim, comparators = comparators, 
-    deduplication = deduplication)
+  }, x = x, y = y, on = on, on_blocking = on_blocking, minsim = minsim, 
+    comparators = comparators, deduplication = deduplication)
   pairs <- rbindlist(pairs)
   if (!keep_simsum) pairs[, simsum := NULL]
   setattr(pairs, "class", c("pairs", class(pairs)))
