@@ -1,7 +1,8 @@
 
 utils::globalVariables(c("..on", "..on_x", "..on_y", ".x", ".y", 
   "..vars", "..var", "..cmp", "..score", "..threshold", "simsum",
-  "mpost", "mprob", "uprob", "upost", "weight", "n", ".id"))
+  "mpost", "mprob", "uprob", "upost", "weight", "n", ".id", "N", 
+  "M"))
 
 
 reclin_env <- new.env(parent = emptyenv())
